==> worker_2.19.6.orig.tar.bz2: worker-2.19.6/src/changesymlinkop.h <==
/* changesymlinkop.h
 * This file belongs to Worker, a file manager for UN*X/X11.
 * Copyright (C) 2001-2004,2011 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef CHANGESYMLINKOP_H
#define CHANGESYMLINKOP_H

#include "wdefines.h"
#include "functionproto.h"

class ChangeSymlinkOp:public FunctionProto
{
public:
  ChangeSymlinkOp();
  virtual ~ChangeSymlinkOp();
  ChangeSymlinkOp( const ChangeSymlinkOp &other );
  ChangeSymlinkOp &operator=( const ChangeSymlinkOp &other );

  virtual ChangeSymlinkOp *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
  using FunctionProto::run;
#endif
  int run( WPUContext *wpu, ActionMessage* );
  virtual const char *getDescription();
protected:
  static const char *name;
  // Infos to save

  // temp variables
  Lister *startlister;
  
  int normalmodechangesl( ActionMessage* );
};

#endif

/* Local Variables: */
/* mode:c++ */
/* End: */

==> worker_3.15.4.orig.tar.bz2: worker-3.15.4/src/changesymlinkop.h <==
/* changesymlinkop.h
 * This file belongs to Worker, a file manager for UN*X/X11.
 * Copyright (C) 2001-2015 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef CHANGESYMLINKOP_H
#define CHANGESYMLINKOP_H

#include "wdefines.h"
#include "functionproto.h"

class ChangeSymlinkOp:public FunctionProto
{
public:
  ChangeSymlinkOp();
  virtual ~ChangeSymlinkOp();
  ChangeSymlinkOp( const ChangeSymlinkOp &other );
  ChangeSymlinkOp &operator=( const ChangeSymlinkOp &other );

  virtual ChangeSymlinkOp *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();

  using FunctionProto::run;
  int run( WPUContext *wpu, ActionMessage* );

  const char *getDescription();
  int configure();
  bool save(Datei*);

  typedef enum { CHANGESYMLINK_EDIT,
                 CHANGESYMLINK_MAKE_ABSOLUTE,
                 CHANGESYMLINK_MAKE_RELATIVE
  } changesymlink_mode_t;

  void setMode( changesymlink_mode_t nv );
protected:
  static const char *name;
  // Infos to save
  changesymlink_mode_t m_mode;

  // temp variables
  Lister *startlister;
  changesymlink_mode_t tmode;

  int normalmodechangesl( ActionMessage* );
};

#endif

/* Local Variables: */
/* mode:c++ */
/* End: */
